.. image:: https://img.shields.io/circleci/project/github/jamescooke/factory_djoy/master.svg
    :alt: CircleCI build
    :target: https://circleci.com/gh/jamescooke/factory_djoy/tree/master

.. image:: https://img.shields.io/readthedocs/factory-djoy.svg
    :alt: Read the Docs
    :target: https://factory-djoy.readthedocs.io/

.. image:: https://img.shields.io/pypi/v/factory_djoy.svg
    :alt: PyPI version
    :target: https://pypi.org/project/factory_djoy/

.. image:: https://img.shields.io/pypi/pyversions/factory_djoy.svg
    :alt: Python version
    :target: https://pypi.org/project/factory_djoy/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: factory_djoy is licensed under the MIT License
    :target: https://raw.githubusercontent.com/jamescooke/factory_djoy/master/LICENSE

Factory Djoy
============

Simple wrappers around Factory Boy for Django which call ``full_clean`` when
creating instances to ensure that only valid data enters your Django database.

Compatible with:

* Django 1.11.

* Python 2.7, 3.5 and 3.6.

* Factory Boy version 2.7 or greater.


Resources
---------

* `Documentation on ReadTheDocs <https://factory-djoy.readthedocs.io/>`_

* `Package on PyPI <https://pypi.python.org/pypi/factory_djoy>`_

* `Source code on GitHub <https://github.com/jamescooke/factory_djoy>`_

* `Licensed on MIT <https://raw.githubusercontent.com/jamescooke/factory_djoy/master/LICENSE>`_

* `Changelog <https://github.com/jamescooke/factory_djoy/blob/master/RELEASE_NOTES.rst>`_
